bark-cli 0.1.0-beta.2
CLI for the bitcoin Ark protocol built by Second
Crate
Builds
Feature flags
Size
Source code size: 146.24 kB
This is the summed size of all the files inside the crates.io package for this release.
Ø build duration
all releases: 10s
Average build duration of
successful
builds in releases after 2024-10-23.
Links
crates.io
Dependencies
anyhow ^1.0
normal
ark-lib ^0.1.0-beta.2
normal
bark-bitcoin-ext ^0.1.0-beta.2
normal
bark-json ^0.1.0-beta.2
normal
bark-server-rpc ^0.1.0-beta.2
normal
bark-wallet ^0.1.0-beta.2
normal
bip39 ^2.0.0
normal
bitcoin ^0.32
normal
chrono ^0.4
normal
clap ^4.4.18
normal
env_logger ^0.11.8
normal
home =0.5.9
normal
lightning ^0.1.1
normal
lightning-invoice ^0.33.2
normal
lnurl-rs ^0.9.0
normal
log ^0.4.27
normal
serde ^1.0.219
normal
serde_json ^1
normal
tokio ^1.35
normal
toml ^0.8.19
normal
tonic ^0.14.2
normal
Versions
0.1.2
(2026-04-09)
0.1.1
(2026-04-08)
0.1.0
(2026-04-04)
0.1.0-beta.9
(2026-03-25)
0.1.0-beta.8
(2026-03-06)
0.1.0-beta.7
(2026-01-28)
0.1.0-beta.6
(2026-01-23)
0.1.0-beta.5
(2025-12-24)
0.1.0-beta.4
(2025-11-20)
0.1.0-beta.3
(2025-11-18)
0.1.0-beta.2
(2025-11-04)
0.0.0
(2024-07-25)
Owners
bark-cli-0.1.0-beta.2 is not a library.
Visit the last successful build:
bark-cli-0.0.0