pub struct Revocation {
pub key: PublicKey,
}Expand description
Revocation keypair derived when a payment is determined to have failed; the public key is used to ask the server to cosign a claim back to us.
Fields
key: PublicKeyTrait Implementations
Sourceimpl Clone for Revocation
impl Clone for Revocation
Sourcefn clone(&self) -> Revocation
fn clone(&self) -> Revocation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Revocation
impl Debug for Revocation
Sourceimpl<'de> Deserialize<'de> for Revocation
impl<'de> Deserialize<'de> for Revocation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Revocation
Sourceimpl PartialEq for Revocation
impl PartialEq for Revocation
Sourcefn eq(&self, other: &Revocation) -> bool
fn eq(&self, other: &Revocation) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for Revocation
impl Serialize for Revocation
impl StructuralPartialEq for Revocation