pub enum WalletNotification {
MovementCreated {
movement: Movement,
},
MovementUpdated {
movement: Movement,
},
ChannelLagging,
}Expand description
A notification emitted by the wallet.
Variants
MovementCreated
A new movement was created
MovementUpdated
An existing movement was updated
ChannelLagging
You have missed some notifications because the channel was full
This happens when you are not consuming the notifications fast enough and the buffer filled up.