pub struct AvailablePaymentMethod {
pub method: PaymentMethod,
pub errors: Vec<PaymentMethodParsingError>,
}Expand description
A single payment option with its validation issues.
A option with a non-empty errors list may still be
presented to the user, but should be flagged as problematic.
Fields
method: PaymentMethoderrors: Vec<PaymentMethodParsingError>Trait Implementations
Sourceimpl Clone for AvailablePaymentMethod
impl Clone for AvailablePaymentMethod
Sourcefn clone(&self) -> AvailablePaymentMethod
fn clone(&self) -> AvailablePaymentMethod
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AvailablePaymentMethod
impl Debug for AvailablePaymentMethod
Sourceimpl From<AvailablePaymentMethod> for PaymentRequest
impl From<AvailablePaymentMethod> for PaymentRequest
Sourcefn from(option: AvailablePaymentMethod) -> Self
fn from(option: AvailablePaymentMethod) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for AvailablePaymentMethod
impl PartialEq for AvailablePaymentMethod
Sourcefn eq(&self, other: &AvailablePaymentMethod) -> bool
fn eq(&self, other: &AvailablePaymentMethod) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for AvailablePaymentMethod
impl StructuralPartialEq for AvailablePaymentMethod