pub enum RoundFlowKind {
DelegatedPending,
Pending,
Ongoing,
AwaitingConfirmations,
Failed,
Canceled,
}Expand description
Type enum of RoundFlowState.
Variants
DelegatedPending
Delegated participation waiting for its round
Pending
Interactive participation waiting for its round
Ongoing
The interactive part is being played out with the server
AwaitingConfirmations
The round finished and we are waiting for its funding tx to confirm
Failed
The participation failed
Canceled
The user canceled the participation