pub struct WalletSeed { /* private fields */ }Expand description
Struct representing an extended private key derived from a wallet’s seed, used to derive child VTXO keypairs
The VTXO seed is derived by applying a hardened derivation step at index 350 from the wallet’s seed.
Implementations
Sourceimpl WalletSeed
impl WalletSeed
Sourcepub fn new_from_seed(network: Network, seed: &[u8; 64]) -> Self
pub fn new_from_seed(network: Network, seed: &[u8; 64]) -> Self
Create a new WalletSeed from a given BIP-32 master seed
Sourcepub fn new_from_mnemonic(network: Network, mnemonic: &Mnemonic) -> Self
pub fn new_from_mnemonic(network: Network, mnemonic: &Mnemonic) -> Self
Create a new WalletSeed from a given BIP-39 Mnemonic
pub fn fingerprint(&self) -> Fingerprint