pub struct TipSubscription { /* private fields */ }Expand description
A subscription to tip changes handed out by TipWatcher::subscribe.
Keeps the watcher task alive for as long as it is held.
Implementations