pub enum WalletNotification {
MovementCreated {
movement: Movement,
},
MovementUpdated {
movement: Movement,
},
ChannelLagging,
}Expand description
A notification emitted by the wallet.
Variants
MovementCreated
A new movement was created
MovementUpdated
An existing movement was updated
ChannelLagging
You have missed some notifications because the channel was full
This happens when you are not consuming the notifications fast enough and the buffer filled up.
Implementations
Sourceimpl WalletNotification
impl WalletNotification
Sourcepub fn movement(&self) -> Option<&Movement>
pub fn movement(&self) -> Option<&Movement>
Get the movement for this notification if it’s movement-related
Sourcepub fn lightning_invoice(&self) -> Option<&Invoice>
pub fn lightning_invoice(&self) -> Option<&Invoice>
Get the Lightning invoice associated with this notification
Returns None for notifications that are not Lightning payments.
Sourcepub fn lightning_offer(&self) -> Option<&Offer>
pub fn lightning_offer(&self) -> Option<&Offer>
Get the Lightning offer associated with this notification
Returns None for notifications that don’t have an offer.
Sourcepub fn lightning_payment_hash(&self) -> Option<PaymentHash>
pub fn lightning_payment_hash(&self) -> Option<PaymentHash>
Get the Lightning payment hash associated with this notification
Returns None for notifications that are not Lightning payments.