pub enum ExitState {
Start(ExitStartState),
Processing(ExitProcessingState),
AwaitingDelta(ExitAwaitingDeltaState),
Claimable(ExitClaimableState),
ClaimInProgress(ExitClaimInProgressState),
Claimed(ExitClaimedState),
}Expand description
A utility type to wrap ExitState children so they can be easily serialized. This also helps with debugging a lot!
Variants
Start(ExitStartState)
Processing(ExitProcessingState)
AwaitingDelta(ExitAwaitingDeltaState)
Claimable(ExitClaimableState)
ClaimInProgress(ExitClaimInProgressState)
Claimed(ExitClaimedState)
Implementations
Sourceimpl ExitState
impl ExitState
pub fn new_start(tip: BlockHeight) -> Self
pub fn new_processing<T: IntoIterator<Item = Txid>>( tip: BlockHeight, txids: T, ) -> Self
pub fn new_processing_from_transactions( tip: BlockHeight, transactions: Vec<ExitTx>, ) -> Self
pub fn new_awaiting_delta( tip: BlockHeight, confirmed_block: BlockRef, wait_delta: BlockDelta, ) -> Self
pub fn new_claimable( tip: BlockHeight, claimable_since: BlockRef, last_scanned_block: Option<BlockRef>, ) -> Self
pub fn new_claim_in_progress( tip: BlockHeight, claimable_since: BlockRef, claim_txid: Txid, ) -> Self
pub fn new_claimed(tip: BlockHeight, txid: Txid, block: BlockRef) -> Self
Sourcepub fn is_pending(&self) -> bool
pub fn is_pending(&self) -> bool
Checks if the state is awaiting the confirmation of every exit transaction in the tree and the exit delta required for the VTXO to become claimable.
Note: This excludes the claimable state, use ExitState::is_claimable for that.
Sourcepub fn is_claimable(&self) -> bool
pub fn is_claimable(&self) -> bool
A simple helper for ExitState::Claimable, at this point an exit can be spent on-chain and redeemed into a UTXO controlled by the user.
pub fn requires_confirmations(&self) -> bool
pub fn claimable_height(&self) -> Option<BlockHeight>