pub struct FeeEstimate {
pub gross_amount: Amount,
pub fee: Amount,
pub net_amount: Amount,
pub vtxos_spent: Vec<VtxoId>,
}Expand description
Result of a fee estimation containing the total cost, fee amount, and VTXOs used. It’s very important to consider that fees can change over time, so you should expect to renew this estimate frequently when presenting this information to users.
Fields
gross_amount: AmountThe total amount including fees.
fee: AmountThe fee amount charged by the server.
net_amount: AmountThe amount excluding fees. For sends, this is the amount the recipient receives. For receives, this is the amount the user gets.
vtxos_spent: Vec<VtxoId>The VTXOs that would be used for this operation, if necessary.
Implementations